@@ -45,6 +45,11 @@
 		return $favicon;
 	}
 
+	if (isset($_GET['oidc-silent-refresh'])) {
+		include('server/includes/templates/oidc-silent-refresh.php');
+		die();
+	}
+
 	// If the user wants to logout (and is not using single-signon)
 	// then destroy the session and redirect to this page, so the login page
 	// will be shown
@@ -84,6 +89,7 @@
 		// Get language from the cookie, or from the language that is set by the admin
 		$Language = new Language();
 		$lang = isset($_COOKIE['lang']) ? $_COOKIE['lang'] : LANG;
+		$lang = $Language->resolveLanguage($lang);
 		$Language->setLanguage($lang);
 
 		// If GET parameter 'load' is defined, we defer handling to the load.php script
@@ -125,7 +131,11 @@
 		$favicon = getFavicon(Theming::getActiveTheme());
 
 		// Include the login template
-		include(BASE_PATH . 'server/includes/templates/login.php');
+		if (OIDC_ISS === "") {
+			include(BASE_PATH . 'server/includes/templates/login.php');
+		} else {
+			include(BASE_PATH . 'server/includes/templates/oidc.php');
+		}
 		die();
 	}
 
@@ -172,7 +182,13 @@
 	// Instantiate Plugin Manager and init the plugins (btw: globals suck)
 	$GLOBALS['PluginManager'] = new PluginManager(ENABLE_PLUGINS);
 	$GLOBALS['PluginManager']->detectPlugins(DISABLED_PLUGINS_LIST);
+
+	// Initialize plugins and prevent any output which might be written as
+	// plugins might be uncleanly output white-space and other stuff. We must
+	// not allow this here as it can destroy the response data.
+	ob_start();
 	$GLOBALS['PluginManager']->initPlugins(DEBUG_LOADER);
+	ob_end_clean();
 
 	$Language = new Language();
 
@@ -232,6 +248,7 @@
 	$favicon = getFavicon(Theming::getActiveTheme());
 	$hideFavorites = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/hide_favorites") ? 'hideFavorites' : '';
 	$scrollFavorites = $GLOBALS["settings"]->get("zarafa/v1/contexts/hierarchy/scroll_favorites") ? 'scrollFavorites' : '';
+	$unreadBorders = $GLOBALS["settings"]->get("zarafa/v1/main/unread_borders") ? 'k-unreadborders' : '';
 
 	// If GET parameter 'load' is defined, we defer handling to the load.php script
 	if ( isset($_GET['load']) ) {
@@ -239,6 +256,11 @@
 		die();
 	}
 
+	// Load OIDC JavaScript for refreshing of the token.
+	if (OIDC_ISS !== "") {
+		require_once(BASE_PATH . 'client/oidc.js.php');
+	}
+
 	if (!DISABLE_WELCOME_SCREEN && $GLOBALS["settings"]->get("zarafa/v1/main/show_welcome") !== false) {
 
 		// These hooks are defined twice (also when there is a "load" argument supplied)
