@@ -45,6 +45,9 @@ class Pluginfilepreviewer extends Plugin {
 							'enable' => PLUGIN_FILEPREVIEWER_USER_DEFAULT_ENABLE,
 							'config_pdf_default_zoom' => PLUGIN_FILEPREVIEWER_PDF_DEFAULT_ZOOM,
 							'config_odf_default_zoom' => PLUGIN_FILEPREVIEWER_ODF_DEFAULT_ZOOM,
+							// WebApp unfortunately does not have the path to the plugins at the client side,
+							// so we will pass it ourselves through the settings
+							'path' => PATH_PLUGIN_DIR . '/filepreviewer',
 						)
 					)
 				)
