@@ -228,12 +228,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 				$this->set_user($GLOBALS['mapisession']->getUserName());
 				$password = $_SESSION['password']; 
 				if(function_exists('openssl_decrypt')) {
-					// In PHP 5.3.3 the iv parameter was added
-					if(version_compare(phpversion(), "5.3.3", "<")) {
-						$this->set_pass(openssl_decrypt($password, "des-ede3-cbc", PASSWORD_KEY, 0));
-					} else {
-						$this->set_pass(openssl_decrypt($password, "des-ede3-cbc", PASSWORD_KEY, 0, PASSWORD_IV));
-					}
+					$this->set_pass(openssl_decrypt($password, "des-ede3-cbc", PASSWORD_KEY, 0, PASSWORD_IV));
 				}
 			}
 		}
@@ -274,7 +269,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	public function set_ssl($ssl)
 	{
 		$this->ssl = $ssl ? true : false;
-		$this->log('SSL extention was set to ' . $this->ssl);
+		$this->log('SSL extension was set to ' . $this->ssl);
 	}
 
 	/**
@@ -302,7 +297,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	}
 
 	/**
-	 * set user name for authentification
+	 * set user name for authentication
 	 *
 	 * @param string $user username
 	 *
@@ -314,7 +309,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	}
 
 	/**
-	 * Set password for authentification
+	 * Set password for authentication
 	 *
 	 * @param string $pass password
 	 *
@@ -376,7 +371,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	}
 
 	/**
-	 * show content of a diretory
+	 * show content of a directory
 	 *
 	 * @param string $path directory path
 	 * @param boolean $hidefirst Optional parameter to hide the root entry. Default true
@@ -454,7 +449,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	}
 
 	/**
-	 * create a new diretory
+	 * create a new directory
 	 *
 	 * @param string $dir directory path
 	 *
@@ -909,6 +904,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 			case CURLE_COULDNT_CONNECT:
 			case CURLE_OPERATION_TIMEOUTED:
 			case self::WD_ERR_UNREACHABLE:
+			case self::WD_ERR_NOTALLOWED:
 				$msg = dgettext('plugin_files', 'File-server is not reachable. Wrong IP entered?');
 				break;
 			case self::WD_ERR_NOTALLOWED:
