@@ -168,6 +168,55 @@ class Theming
 		return $cssFiles;
 	}
 
+	/**
+	 * Returns the value that is assigned to a property by the active theme
+	 * or null otherwise.
+	 * Currently only implemented for JSON themes.
+	 * @return String The value that the active theme has set for the property,
+	 * or NULL.
+	 */
+	public static function getThemeProperty($propName) {
+		$theme = Theming::getActiveTheme();
+		if ( !Theming::isJsonTheme($theme) ) {
+			return false;
+		}
+
+		$props = Theming::getJsonThemeProps($theme);
+		if ( !isset($props[$propName]) ) {
+			return false;
+		}
+
+		return $props[$propName];
+	}
+
+	/**
+	 * Returns the color that the active theme has set for the primary color
+	 * of the icons. Currently only supported for JSON themes.
+	 * Note: Only SVG icons of an iconset that has defined the primary color
+	 * can be 'recolored'.
+	 * @return String The color that the active theme has set for the primary
+	 * color of the icons, or FALSE.
+	 */
+	public static function getPrimaryIconColor() {
+		$val = Theming::getThemeProperty('icons-primary-color');
+
+		return $val !== null ? $val : false;
+	}
+
+	/**
+	 * Returns the color that the active theme has set for the secondary color
+	 * of the icons. Currently only supported for JSON themes.
+	 * Note: Only SVG icons of an iconset that has defined the secondary color
+	 * can be 'recolored'.
+	 * @return String The color that the active theme has set for the secondary
+	 * color of the icons, or FALSE.
+	 */
+	public static function getSecondaryIconColor() {
+		$val = Theming::getThemeProperty('icons-secondary-color');
+
+		return $val !== null ? $val : false;
+	}
+
 	/**
 	 * Checks if a theme is a JSON theme. (Basically this means that it checks if a
 	 * directory with the theme name exists and if that directory contains a file
@@ -282,7 +331,12 @@ class Theming
 
 		if ( $themeProps['primary-color'] ) {
 			if ( !$themeProps['primary-color:hover'] ) {
-				$themeProps['primary-color:hover'] = Colors::darker($themeProps['primary-color'], 10);
+				list(, , $l) = Colors::rgb2hsl(Colors::colorString2Object($themeProps['primary-color']));
+				if ( $l > 20 ) {
+					$themeProps['primary-color:hover'] = Colors::darker($themeProps['primary-color'], 10);
+				} else {
+					$themeProps['primary-color:hover'] = Colors::lighter($themeProps['primary-color'], 20);
+				}
 			}
 
 			if ( !$themeProps['mainbar-text-color'] ) {
@@ -299,14 +353,16 @@ class Theming
 		if ( $themeProps['action-color'] && !$themeProps['action-color:hover'] ) {
 			$themeProps['action-color:hover'] = Colors::darker($themeProps['action-color'], 10);
 		}
-		// Set a text color for the selection-color
-		$hsl = Colors::rgb2hsl($themeProps['selection-color']);
-		if ( $hsl['l'] > 50 ) {
-			$hsl['l'] = 5;
-		} else {
-			$hsl['l'] = 95;
+		if ( isset($themeProps['selection-color']) && !isset($themeProps['selection-text-color']) ) {
+			// Set a text color for the selection-color
+			$hsl = Colors::rgb2hsl($themeProps['selection-color']);
+			if ( $hsl['l'] > 50 ) {
+				$hsl['l'] = 5;
+			} else {
+				$hsl['l'] = 95;
+			}
+			$themeProps['selection-text-color'] = Colors::colorObject2string(Colors::hsl2rgb($hsl));
 		}
-		$themeProps['selection-text-color'] = Colors::colorObject2string(Colors::hsl2rgb($hsl));
 
 		if ( isset($themeProps['background-image']) ) {
 			$themeProps['background-image'] = Theming::fixUrl($themeProps['background-image'], $theme);
@@ -314,6 +370,9 @@ class Theming
 		if ( isset($themeProps['logo-large']) ) {
 			$themeProps['logo-large'] = Theming::fixUrl($themeProps['logo-large'], $theme);
 		}
+		if ( isset($themeProps['logo-small']) ) {
+			$themeProps['logo-small'] = Theming::fixUrl($themeProps['logo-small'], $theme);
+		}
 		if ( isset($themeProps['logo-large']) && !isset($themeProps['logo-small']) ) {
 			$themeProps['logo-small'] = $themeProps['logo-large'];
 		}
@@ -376,6 +435,11 @@ class Theming
 			body #zarafa-mainmenu.zarafa-maintabbar > .x-toolbar-ct {
 				background-color: {{primary-color}};
 			}
+			/* Unread items */
+			.k-unreadborders .x-grid3-row.x-grid3-row-collapsed.mail_unread > table,
+			.k-unreadborders .x-grid3-row.x-grid3-row-expanded.mail_unread > table {
+		        	border-left: 4px solid {{primary-color}} !important;
+			}
 		',
 
 		'primary-color:hover' => '
@@ -488,6 +552,26 @@ class Theming
 			.x-btn.zarafa-action.x-btn-focus .x-btn-small, .x-btn.zarafa-action.x-btn-focus .x-btn-medium, .x-btn.zarafa-action.x-btn-focus .x-btn-large {
 				background: {{action-color}} !important;
 			}
+			/* Selected calendar */
+			.zarafa-calendar-tabarea-stroke.zarafa-calendar-tab-selected {
+				border-top-color: {{action-color}};
+			}
+			.x-date-picker .x-date-inner td.x-date-weeknumber a,
+			.zarafa-hierarchy-node-total-count span.zarafa-hierarchy-node-counter,
+			.zarafa-hierarchy-node-unread-count span.zarafa-hierarchy-node-counter {
+				color: {{action-color}};
+			}
+			.x-date-picker .x-date-inner td.x-date-today a {
+				border-color: {{action-color}};
+			}
+			.zarafa-freebusy-panel .x-freebusy-timeline-container .x-freebusy-header .x-freebusy-header-body .x-freebusy-timeline-day.x-freebusy-timeline-day-current,
+			.zarafa-freebusy-panel .x-freebusy-timeline-container .x-freebusy-body .x-freebusy-background .x-freebusy-timeline-day.x-freebusy-timeline-day-current {
+				border-right-color: {{action-color}};
+			}
+			.zarafa-freebusy-panel .x-freebusy-timeline-container .x-freebusy-header .x-freebusy-header-body .x-freebusy-timeline-day.x-freebusy-timeline-day-current table tr.x-freebusy-timeline-hour td:first-child,
+			.zarafa-freebusy-panel .x-freebusy-timeline-container .x-freebusy-body .x-freebusy-background .x-freebusy-timeline-day.x-freebusy-timeline-day-current td:first-child {
+				border-left-color: {{action-color}};
+			}
 		',
 
 		'action-color:hover' => '
@@ -560,6 +644,17 @@ class Theming
 			.zarafa-mailcreatepanel > .x-panel-bwrap > .x-panel-body .zarafa-mailcreatepanel-extrainfo div {
 				background: {{selection-color}} !important;
 			}
+
+			/* Selected mail item */
+			.k-unreadborders .x-grid3-row.x-grid3-row-expanded.mail_read.x-grid3-row-selected > table {
+			        border-left: 4px solid {{selection-color}} !important;
+			}
+
+			/* Hover selected item */
+			.k-unreadborders .x-grid3-row.x-grid3-row-expanded.mail_read.x-grid3-row-selected.x-grid3-row-over > table,
+			.k-unreadborders .x-grid3-row.x-grid3-row-collapsed.mail_read.x-grid3-row-selected > table {
+			        border-left: 4px solid {{selection-color}} !important;
+			}
 		',
 
 		'selection-text-color' => '
