@@ -117,31 +117,6 @@ class FileLoader {
 		return $jsLoadingSequence;
 	}
 
-	/**
-	 * Obtain the list of WebApp files
-	 *
-	 * @param number $load The LOAD_RELEASE | LOAD_DEBUG | LOAD_SOURCE flag
-	 * to indicate which files should be loaded.
-	 * @return array The array of CSS files
-	 */
-	public function getZarafaCSSFiles($load)
-	{
-		$cssLoadingSequence = array();
-
-		if ($load == LOAD_RELEASE) {
-			$cssLoadingSequence[] = "client/resources/css/kopano.css";
-		} else if ($load == LOAD_DEBUG) {
-			$cssLoadingSequence[] = "client/resources/css/kopano.css";
-		} else {
-			$cssLoadingSequence = array_merge(
-				$cssLoadingSequence,
-				$this->getListOfFiles('css', 'client/resources/css', false)
-			);
-		}
-
-		return $cssLoadingSequence;
-	}
-
 	/**
 	 * Obtain the list of all Javascript files as registered by the plugins.
 	 *
@@ -216,16 +191,24 @@ class FileLoader {
 	 */
 	public function printFiles($files, $template = '{file}', $base = false, $concatVersion = true)
 	{
-		$version = trim(file_get_contents('version'));
 		foreach($files as $file) {
 			$file = $base === true ? basename($file) : $file;
 			if($concatVersion) {
-				$file = $file."?version=".$version;
+				$file = $file."?version=".$this->getVersion();
 			}
 			echo str_replace('{file}', $file, $template) . PHP_EOL;
 		}
 	}
 
+	/**
+	 * Return WebApp version.
+	 * @return String returns WebApp version
+	 */
+	public function getVersion()
+	{
+		return trim(file_get_contents('version'));
+	}
+
 	/**
 	 * getJavascriptFiles
 	 *
@@ -323,7 +306,7 @@ class FileLoader {
 	 * classed which are depended upon by the given files).
 	 * @return Array List of files that are sorted in the correct sequence
 	 */
-	public function buildJSLoadingSequence($files, $coreFiles = Array(), $libFiles = Array()){
+	private function buildJSLoadingSequence($files, $coreFiles = Array(), $libFiles = Array()){
 		// Create a lookup table to easily get the classes which are defined in the library files
 		$libFileLookup = Array();
 		// Create a lookup table to easily get the name of the file the class is defined in
@@ -543,8 +526,8 @@ class FileLoader {
 			while(!feof($fh)){
 				$fc .= fgets($fh, 4096);
 			}
+			fclose($fh);
 		}
-		fclose($fh);
 		return $fc;
 	}
 
@@ -562,16 +545,12 @@ class FileLoader {
 			ob_start();
 		}
 
+		list($extjsFiles, $webappFiles, $pluginFiles, $remoteFiles) = $this->getJsFiles();
+
 		$jsTemplate = "\t\t<script type=\"text/javascript\" src=\"{file}\"></script>";
-		$extjsFiles = $this->getExtjsJavascriptFiles(DEBUG_LOADER);
 		$this->printFiles($extjsFiles, $jsTemplate);
-		$webappFiles = $this->getZarafaJavascriptFiles(DEBUG_LOADER, $extjsFiles);
 		$this->printFiles($webappFiles, $jsTemplate);
-
-		$pluginFiles = $this->getPluginJavascriptFiles(DEBUG_LOADER, array_merge($extjsFiles, $webappFiles));
 		$this->printFiles($pluginFiles, $jsTemplate);
-
-		$remoteFiles = $this->getRemoteJavascriptFiles(DEBUG_LOADER);
 		$this->printFiles($remoteFiles, $jsTemplate);
 
 		if ($this->source) {
@@ -582,6 +561,24 @@ class FileLoader {
 		}
 	}
 
+	/**
+	 * Returns an array with all javascript files. The array has four entries, for the ExtJS files,
+	 * the Zarafa files, the plugin files and the remote files respectively.
+	 * This function will make sure that the directories are read only once.
+	 *
+	 * @return array An array that contains the names of all the javascript files that should be loaded
+	 */
+	private function getJsFiles() {
+		if ( !isset($this->extjsfiles) ){
+			$this->extjsFiles = $this->getExtjsJavascriptFiles(DEBUG_LOADER);
+			$this->webappFiles = $this->getZarafaJavascriptFiles(DEBUG_LOADER, $this->extjsFiles);
+			$this->pluginFiles = $this->getPluginJavascriptFiles(DEBUG_LOADER, array_merge($this->extjsFiles, $this->webappFiles));
+			$this->remoteFiles = $this->getRemoteJavascriptFiles(DEBUG_LOADER);
+		}
+
+		return array($this->extjsFiles, $this->webappFiles, $this->pluginFiles, $this->remoteFiles);
+	}
+
 	/**
 	 * The CSS load order for WebApp
 	 */
@@ -591,31 +588,26 @@ class FileLoader {
 		$extjsFiles = $this->getExtjsCSSFiles(DEBUG_LOADER);
 		$this->printFiles($extjsFiles, $cssTemplate);
 
-		$webappFiles = $this->getZarafaCSSFiles(DEBUG_LOADER);
-		$this->printFiles($webappFiles, $cssTemplate);
+		// Since we only have one css file, we can add that directly
+		$this->printFiles(array("client/resources/css/kopano.css"), $cssTemplate);
 
 		$pluginFiles = $this->getPluginCSSFiles(DEBUG_LOADER);
 		$this->printFiles($pluginFiles, $cssTemplate);
 
 		$remoteFiles = $this->getRemoteCSSFiles(DEBUG_LOADER);
 		$this->printFiles($remoteFiles, $cssTemplate);
-
-		/* Add the styling of the theme */
-		$css = Theming::getCss(Theming::getActiveTheme());
-		foreach ( $css as $file ) {
-			echo '<link rel="stylesheet" type="text/css" href="'.$file.'">';
-		}
 	}
 
 	/**
-	 * Checks if the any JavaScript or CSS files on disk have been changed
+	 * Checks if the JavaScript or CSS files on disk have been changed
 	 * and writes a new md5 of the files to the disk.
 	 *
 	 * return boolean False if cache is outdated
 	 */
-	public function cacheExists()
+	private function cacheExists()
 	{
-		$files = [$this->getJavascriptFiles('client'), $this->getJavascriptFiles('plugins')];
+		list($extjsFiles, $webappFiles, $pluginFiles, $remoteFiles) = $this->getJsFiles();
+		$files = [$extjsFiles, $webappFiles, $pluginFiles, $remoteFiles];
 		$md5 = md5(json_encode($files));
 
 		if (!file_exists($this->cacheSum) || file_get_contents($this->cacheSum) !== $md5) {
