@@ -12,11 +12,14 @@ $serverConfig = array_merge($serverConfig, array(
 	'disable_full_gab'				=> DISABLE_FULL_GAB,
 	'enable_shared_rules'			=> ENABLE_SHARED_RULES,
 	'always_enabled_plugins'		=> $GLOBALS['PluginManager']->expandPluginList(ALWAYS_ENABLED_PLUGINS_LIST),
+	'disable_whats_new_dialog'		=> DISABLE_WHATS_NEW_DIALOG,
 	'enable_advanced_settings'		=> ENABLE_ADVANCED_SETTINGS ? true : false,
 	'post_max_size'					=> getMaxPostRequestSize(),
 	'max_file_uploads'				=> getMaxFileUploads(),
 	'client_timeout' 				=> defined('CLIENT_TIMEOUT') && is_numeric(CLIENT_TIMEOUT) && CLIENT_TIMEOUT>0 ? CLIENT_TIMEOUT : false,
 	'active_theme'					=> Theming::getActiveTheme(),
+	'icons_primary_color'			=> Theming::getPrimaryIconColor(),
+	'icons_secondary_color'			=> Theming::getSecondaryIconColor(),
 	'json_themes'					=> Theming::getJsonThemes(),
 	'iconsets'						=> Iconsets::getIconsets(),
 	'active_iconset'				=> Iconsets::getActiveIconset(),
@@ -33,6 +36,9 @@ $serverConfig = array_merge($serverConfig, array(
 											'powerpaste_allow_local_images' => POWERPASTE_ALLOW_LOCAL_IMAGES,
 										),
 	'shared_store_polling_interval' => SHARED_STORE_POLLING_INTERVAL,
+	'prefetch_email_count' => PREFETCH_EMAIL_COUNT,
+	'prefetch_email_interval' => PREFETCH_EMAIL_INTERVAL,
+	'oidc_enabled' => OIDC_ISS,
 ));
 if ( CONTACT_PREFIX ){
 	$serverConfig['contact_prefix'] = json_decode(CONTACT_PREFIX);
@@ -70,7 +76,7 @@ if ( defined('ADDITIONAL_CATEGORIES') ){
 		<link id="kopano-iconset-stylesheet" rel="stylesheet" href="<?php echo $iconsetStylesheet; ?>" >
 	</head>
 
-	<body class="zarafa-webclient theme-<?php echo strtolower($theme ? $theme : 'basic'); echo ' '. $hideFavorites; echo ' '. $scrollFavorites ?>">
+	<body class="zarafa-webclient theme-<?php echo strtolower($theme ? $theme : 'basic'); echo ' '. $hideFavorites; echo ' '. $scrollFavorites; echo ' '. $unreadBorders ?>">
 		<div id="loading-mask">
 			<div id="form-container" class="loading" style="visibility: hidden;">
 				<div id="bg"></div>
