@@ -17,15 +17,21 @@ $loader = new FileLoader();
 		<?php
 			$loader->cssOrder();
 			echo Theming::getStyles($theme);
+			$iconsetStylesheet = Iconsets::getActiveStylesheet();
 		?>
 	</head>
 
 	<body class="theme-<?php echo strtolower($theme ? $theme : 'basic') ?>">
 		<?php
 			$jsTemplate = "\t\t<script type=\"text/javascript\" src=\"{file}\"></script>";
-			$extjsFiles[] = "client/tinymce/tinymce.js";
+			if (DEBUG_LOADER === LOAD_RELEASE) {
+				$extjsFiles[] = "client/tinymce/tinymce.min.js";
+			} else {
+				$extjsFiles[] = "client/tinymce/tinymce.js";
+			}
 			$loader->printFiles($extjsFiles, $jsTemplate);
 		?>
+		<link id="kopano-iconset-stylesheet" rel="stylesheet" href="<?php echo $iconsetStylesheet; ?>" >
 		<script>
 
 			/**
